================
Frontera Contrib
================

Quick start
-----------

1. Add "frontera_contrib" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'frontera_contrib',
    ]
